@@ -50,27 +50,27 @@ def select_parse(command):
     if args.startswith('!'):
         args = args.replace('!', '', 1)
 
-        def selector(tiddlers):
+        def selector(tiddlers, indexable=False, environ={}):
             return select_by_attribute(attribute, args, tiddlers, negate=True)
 
     elif args.startswith('<'):
         args = args.replace('<', '', 1)
 
-        def selector(tiddlers):
+        def selector(tiddlers, indexable=False, environ={}):
             return select_relative_attribute(attribute, args, tiddlers,
                     lesser=True)
 
     elif args.startswith('>'):
         args = args.replace('>', '', 1)
 
-        def selector(tiddlers):
+        def selector(tiddlers, indexable=False, environ={}):
             return select_relative_attribute(attribute, args, tiddlers,
                     greater=True)
 
     else:
 
-        def selector(tiddlers):
-            return select_by_attribute(attribute, args, tiddlers)
+        def selector(tiddlers, indexable=False, environ={}):
+            return select_by_attribute(attribute, args, tiddlers, indexable=indexable, environ=environ)
 
     return selector
 
@@ -114,12 +114,22 @@ def default_func(tiddler, attribute, value):
             return False
 
 
-def select_by_attribute(attribute, value, tiddlers, negate=False):
+def select_by_attribute(attribute, value, tiddlers, negate=False, indexable=False, environ={}):
     """
     Select tiddlers where value of attribute matches the provide value.
 
     If negate is true, get those that don't match.
     """
+
+    if indexable:
+        indexer = environ.get('tiddlyweb.config', {}).get('indexer', None)
+        if indexer:
+            # If there is an exception, just let it raise.
+            imported_module = __import__(indexer, {}, {}, ['index_query'])
+            # dict keys may not be unicode
+            kwords = {str(attribute): value, 'bag': indexable.name}
+            return imported_module.index_query(environ, **kwords)
+
     select = ATTRIBUTE_SELECTOR.get(attribute, default_func)
     if negate:
         return (tiddler for tiddler in tiddlers if not
@@ -129,11 +139,13 @@ def select_by_attribute(attribute, value, tiddlers, negate=False):
                 select(tiddler, attribute, value))
 
 
-def select_relative_attribute(attribute, value, tiddlers, greater=False, lesser=False):
+def select_relative_attribute(attribute, value, tiddlers,
+        greater=False, lesser=False):
     """
     Select tiddlers that sort greater or less than the provided value
     for the provided attribute.
     """
+
     def normalize_value(value):
         try:
             return value.lower()
@@ -144,9 +156,11 @@ def select_relative_attribute(attribute, value, tiddlers, greater=False, lesser=
 
     if greater:
         return (tiddler for tiddler in tiddlers if
-                func(getattr(tiddler, attribute, tiddler.fields.get(attribute, None))) > func(value))
+                func(getattr(tiddler, attribute, tiddler.fields.get(
+                    attribute, None))) > func(value))
     elif lesser:
         return (tiddler for tiddler in tiddlers if
-                func(getattr(tiddler, attribute, tiddler.fields.get(attribute, None))) < func(value))
+                func(getattr(tiddler, attribute, tiddler.fields.get(
+                    attribute, None))) < func(value))
     else:
         return (tiddler for tiddler in tiddlers)
