@@ -99,7 +99,8 @@ class Serialization(SerializationInterface):
         plus the text of the tiddler.
         """
         tiddler_dict = self._tiddler_dict(tiddler)
-        if tiddler.type and tiddler.type != 'None' and not tiddler.type.startswith('text/'):
+        if (tiddler.type and tiddler.type != 'None' and not
+                tiddler.type.startswith('text/')):
             tiddler_dict['text'] = b64encode(tiddler.text)
         else:
             tiddler_dict['text'] = tiddler.text
@@ -116,7 +117,8 @@ class Serialization(SerializationInterface):
         for key, value in dict_from_input.iteritems():
             if value is not None and key in accepted_keys:
                 setattr(tiddler, key, value)
-        if tiddler.type and tiddler.type != 'None' and not tiddler.type.startswith('text/'):
+        if (tiddler.type and tiddler.type != 'None' and not
+                tiddler.type.startswith('text/')):
             tiddler.text = b64decode(tiddler.text)
 
         return tiddler
@@ -146,6 +148,7 @@ class Serialization(SerializationInterface):
         Make a list of the permissions the current user has
         on this tiddler.
         """
+
         def _read_bag_perms(environ, tiddler):
             perms = []
             if 'tiddlyweb.usersign' in environ:
