@@ -13,11 +13,11 @@ from tiddlyweb.model.policy import \
 from tiddlyweb.store import NoRecipeError, NoBagError, \
         StoreMethodNotImplemented
 from tiddlyweb.serializer import Serializer, NoSerializationError
-from tiddlyweb.web.http import HTTP400, HTTP415, HTTP404
+from tiddlyweb.web.http import HTTP400, HTTP409, HTTP415, HTTP404
 from tiddlyweb.web.sendtiddlers import send_tiddlers
 from tiddlyweb import control
 from tiddlyweb.web import util as web
-from tiddlyweb.web.validator import validate_recipe, InvalidRecipeError
+from tiddlyweb.web.validator import validate_recipe, InvalidBagError
 
 
 def delete(environ, start_response):
@@ -67,7 +67,6 @@ def get_tiddlers(environ, start_response):
     Get the list of tiddlers produced by this
     recipe.
     """
-    filters = environ['tiddlyweb.filters']
     usersign = environ['tiddlyweb.usersign']
     store = environ['tiddlyweb.store']
     recipe = _determine_recipe(environ)
@@ -105,7 +104,7 @@ def get_tiddlers(environ, start_response):
     return send_tiddlers(environ, start_response, tmp_bag)
 
 
-def list(environ, start_response):
+def list_recipes(environ, start_response):
     """
     Get a list of all recipes the current user can read.
     """
@@ -129,7 +128,7 @@ def list(environ, start_response):
         output = serializer.list_recipes(kept_recipes)
     except NoSerializationError:
         raise HTTP415('Content type not supported: %s' % mime_type)
-    
+
     return [output]
 
 
@@ -173,6 +172,7 @@ def put(environ, start_response):
 
     return []
 
+
 def _validate_recipe(environ, recipe):
     """
     Unless recipe is valid raise a 409 with the reason why.
