@@ -11,7 +11,7 @@ from tiddlyweb.serializer import Serializer, NoSerializationError
 from tiddlyweb.util import sha
 from tiddlyweb.web.util import \
         get_serialize_type, http_date_from_timestamp, datetime_from_http_date
-from tiddlyweb.web.http import HTTP400, HTTP404, HTTP304, HTTP415
+from tiddlyweb.web.http import HTTP400, HTTP304, HTTP415
 
 
 def send_tiddlers(environ, start_response, bag):
@@ -34,8 +34,6 @@ def send_tiddlers(environ, start_response, bag):
             searchbag=bag.searchbag)
     tmp_bag.add_tiddlers(tiddlers)
 
-    # If there are no tiddlers in the bag, validation will
-    # raise 404. If incoming Etag is acceptable, will raise 304.
     last_modified, etag = _validate_tiddler_list(environ, tmp_bag)
 
     serialize_type, mime_type = get_serialize_type(environ)
@@ -64,6 +62,21 @@ def send_tiddlers(environ, start_response, bag):
 
 
 def _validate_tiddler_list(environ, bag):
+    """
+    Calculate the Last modified and ETag for
+    the tiddlers in bag. If the ETag matches an
+    incoming If-None-Match, then raise a 304 and
+    don't send the tiddler content. If the modified
+    string in an If-Modified-Since is newer than the
+    last-modified on the tiddlers, raise 304.
+
+    If ETag testing is done, no last modified handling
+    is done, even if the ETag testing fails.
+
+    If no 304 is raised, then just return last-modified
+    and ETag for the caller to use in constructing
+    its HTTP response.
+    """
     last_modified_number = _last_modified_tiddler(bag)
     last_modified = None
     if last_modified_number:
@@ -89,6 +102,11 @@ def _validate_tiddler_list(environ, bag):
 
 
 def _sha_tiddler_titles(bag):
+    """
+    Create a sha digest of the titles of all the
+    tiddlers in the bag. Include the recipe or
+    bag name for disambiguation.
+    """
     digest = sha()
     for tiddler in bag.gen_tiddlers():
         if tiddler.recipe:
@@ -101,8 +119,13 @@ def _sha_tiddler_titles(bag):
 
 
 def _last_modified_tiddler(bag):
-    # If there are no tiddlers, raise a 404
+    """
+    Generate the last modified time for the tiddlers
+    in this bag. It is the most recently modified time
+    of all the tiddlers.
+    """
     try:
-        return str(max(int(tiddler.modified) for tiddler in bag.gen_tiddlers()))
+        return str(max(int(tiddler.modified)
+            for tiddler in bag.gen_tiddlers()))
     except ValueError:
         return ''
