@@ -99,9 +99,8 @@ class HTMLPresenter(object):
 </html>
 """ % (footer_extra, VERSION, environ['tiddlyweb.usersign']['name'])
 
-    # XXX: to make these stackable this can't just
+    # XXX: to make these stackable this shouldn't just
     # be a method, we need some kind of registry.
-
     def header_extra(self, environ):
         """
         Override this in plugins to add to the header.
@@ -136,16 +135,16 @@ class SimpleLog(object):
             req_uri += '?'+environ['QUERY_STRING']
 
         def replacement_start_response(status, headers, exc_info=None):
-            bytes = None
+            size = None
             for name, value in headers:
                 if name.lower() == 'content-length':
-                    bytes = value
-            self.write_log(environ, req_uri, status, bytes)
+                    size = value
+            self.write_log(environ, req_uri, status, size)
             return start_response(status, headers, exc_info)
 
         return self.application(environ, replacement_start_response)
 
-    def write_log(self, environ, req_uri, status, bytes):
+    def write_log(self, environ, req_uri, status, size):
         """
         Print the log info out in a formatted for to stdout.
         """
@@ -154,8 +153,8 @@ class SimpleLog(object):
             environ['REMOTE_USER'] = environ['tiddlyweb.usersign']['name']
         except KeyError:
             pass
-        if bytes is None:
-            bytes = '-'
+        if size is None:
+            size = '-'
         log_format = {
                 'REMOTE_ADDR': environ.get('REMOTE_ADDR') or '-',
                 'REMOTE_USER': environ.get('REMOTE_USER') or '-',
@@ -164,7 +163,7 @@ class SimpleLog(object):
                 'HTTP_VERSION': environ.get('SERVER_PROTOCOL'),
                 'time': time.strftime('%d/%b/%Y:%H:%M:%S ', time.localtime()),
                 'status': status.split(None, 1)[0],
-                'bytes': bytes,
+                'bytes': size,
                 'HTTP_REFERER': environ.get('HTTP_REFERER', '-'),
                 'HTTP_USER_AGENT': environ.get('HTTP_USER_AGENT', '-'),
                 }
@@ -174,14 +173,16 @@ class SimpleLog(object):
 
 class StoreSet(object):
     """
-    WSGI Middleware that sets our choice of Store (tiddlyweb.store) in the environment.
+    WSGI Middleware that sets our choice of Store (tiddlyweb.store)
+    in the environment.
     """
 
     def __init__(self, application):
         self.application = application
 
     def __call__(self, environ, start_response):
-        database = Store(environ['tiddlyweb.config']['server_store'][0], environ)
+        database = Store(environ['tiddlyweb.config']['server_store'][0],
+                environ)
         environ['tiddlyweb.store'] = database
         return self.application(environ, start_response)
 
@@ -195,14 +196,20 @@ class EncodeUTF8(object):
     def __init__(self, application):
         self.application = application
 
-    def _encoder(self, string):
-        # if we are currently unicode, encode to utf-8
-        if type(string) == unicode:
-            string = string.encode('utf-8')
-        return string
-
     def __call__(self, environ, start_response):
-        return [self._encoder(output) for output in self.application(environ, start_response)]
+        return [_encoder(output) for output in
+                self.application(environ, start_response)]
+
+
+def _encoder(string):
+    """
+    Take a potentially unicode string and encode it
+    as UTF-8.
+    """
+    # if we are currently unicode, encode to utf-8
+    if type(string) == unicode:
+        string = string.encode('utf-8')
+    return string
 
 
 class PermissionsExceptor(object):
@@ -244,4 +251,5 @@ class PermissionsExceptor(object):
         if query_string:
             redirect += '?%s' % query_string
         redirect = urllib.quote(redirect, safe='')
-        return '%s/challenge?tiddlyweb_redirect=%s' % (server_base_url(environ), redirect)
+        return '%s/challenge?tiddlyweb_redirect=%s' % (
+                server_base_url(environ), redirect)
